Overview
========

``ftw.dashboard.portlets.favourites`` provides a favorites portlet for your dashboard

The favorite portlet shows links for all your favorites in your Home Folder. In the edit
mode you have also the possibility to remove a single favorite. Additionaly it implements
the site action "add to favorites", which add a current section to your favorites Folder.


Install
=======

- Add ``ftw.dashboard.portlets.favourites`` to your buildout configuration

::

  [instance]
  eggs =
    ftw.dashboard.portlets.favourites

- Run buildout

- Install ``ftw.dashboard.portlets.favourites`` in portal_setup


Links
=====

- Github: https://github.com/4teamwork/ftw.dashboard.portlets.favourites
- Issues: https://github.com/4teamwork/ftw.dashboard.portlets.favourites/issues
- Pypi: http://pypi.python.org/pypi/ftw.dashboard.portlets.favourites
- Continuous integration: https://jenkins.4teamwork.ch/search?q=ftw.dashboard.portlets.favourites


Copyright
=========

This package is copyright by `4teamwork <http://www.4teamwork.ch/>`_.

``ftw.dashboard.portlets.favourites`` is licensed under GNU General Public License, version 2.
